# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from originstamp_client.api_client import ApiClient


class WebhookApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_webhook_status(self, authorization, webhook_request, **kwargs):  # noqa: E501
        """Webhook  # noqa: E501

        RESTful interface to receive the status of a webhook. Based on the input parameters (target URL, hash and currency), we look up the most recent entry in the notification queue.This method is intended to support the webhook integration.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhook_status(authorization, webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param WebhookRequest webhook_request: DTO for registering webhook information. (required)
        :return: DefaultOfWebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_webhook_status_with_http_info(authorization, webhook_request, **kwargs)  # noqa: E501
        else:
            (data) = self.get_webhook_status_with_http_info(authorization, webhook_request, **kwargs)  # noqa: E501
            return data

    def get_webhook_status_with_http_info(self, authorization, webhook_request, **kwargs):  # noqa: E501
        """Webhook  # noqa: E501

        RESTful interface to receive the status of a webhook. Based on the input parameters (target URL, hash and currency), we look up the most recent entry in the notification queue.This method is intended to support the webhook integration.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webhook_status_with_http_info(authorization, webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param WebhookRequest webhook_request: DTO for registering webhook information. (required)
        :return: DefaultOfWebhookResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'webhook_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webhook_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_webhook_status`")  # noqa: E501
        # verify the required parameter 'webhook_request' is set
        if ('webhook_request' not in params or
                params['webhook_request'] is None):
            raise ValueError("Missing the required parameter `webhook_request` when calling `get_webhook_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'webhook_request' in params:
            body_params = params['webhook_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API Key Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/v3/webhook/information', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultOfWebhookResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_webhook_notification(self, authorization, webhook_request, **kwargs):  # noqa: E501
        """Webhook  # noqa: E501

        Method which allows a subscription for a webhook notification. If this method is called, a new entry is added to notification queue that is triggered as soon as a tamper-proof timestamp or the hash is created. An empty data payload means that the entry was created successfully.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_webhook_notification(authorization, webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param WebhookRequest webhook_request: DTO for querying webhook information. (required)
        :return: DefaultOfVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_webhook_notification_with_http_info(authorization, webhook_request, **kwargs)  # noqa: E501
        else:
            (data) = self.register_webhook_notification_with_http_info(authorization, webhook_request, **kwargs)  # noqa: E501
            return data

    def register_webhook_notification_with_http_info(self, authorization, webhook_request, **kwargs):  # noqa: E501
        """Webhook  # noqa: E501

        Method which allows a subscription for a webhook notification. If this method is called, a new entry is added to notification queue that is triggered as soon as a tamper-proof timestamp or the hash is created. An empty data payload means that the entry was created successfully.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_webhook_notification_with_http_info(authorization, webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param WebhookRequest webhook_request: DTO for querying webhook information. (required)
        :return: DefaultOfVoid
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'webhook_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_webhook_notification" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `register_webhook_notification`")  # noqa: E501
        # verify the required parameter 'webhook_request' is set
        if ('webhook_request' not in params or
                params['webhook_request'] is None):
            raise ValueError("Missing the required parameter `webhook_request` when calling `register_webhook_notification`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'webhook_request' in params:
            body_params = params['webhook_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API Key Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/v3/webhook/register', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultOfVoid',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def trigger_timestamp_webhook(self, authorization, manual_webhook_request, **kwargs):  # noqa: E501
        """Dev  # noqa: E501

        With this interface you can trigger manual webhook to see how a webhook looks like. Please use a hash, that was already timestamped before such as https://redir.originstamp.com/hash/9f86d081884c7d659a2feaa0c55ad015a3bf4f1b2b0b822cd15d6c15b0f00a08 . Usually, the webhook is triggered as soon as the tamper-proof time stamp with the selected crypto currency has been created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.trigger_timestamp_webhook(authorization, manual_webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param ManualWebhookRequest manual_webhook_request: DTO for webhook request. (required)
        :return: DefaultOfstring
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.trigger_timestamp_webhook_with_http_info(authorization, manual_webhook_request, **kwargs)  # noqa: E501
        else:
            (data) = self.trigger_timestamp_webhook_with_http_info(authorization, manual_webhook_request, **kwargs)  # noqa: E501
            return data

    def trigger_timestamp_webhook_with_http_info(self, authorization, manual_webhook_request, **kwargs):  # noqa: E501
        """Dev  # noqa: E501

        With this interface you can trigger manual webhook to see how a webhook looks like. Please use a hash, that was already timestamped before such as https://redir.originstamp.com/hash/9f86d081884c7d659a2feaa0c55ad015a3bf4f1b2b0b822cd15d6c15b0f00a08 . Usually, the webhook is triggered as soon as the tamper-proof time stamp with the selected crypto currency has been created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.trigger_timestamp_webhook_with_http_info(authorization, manual_webhook_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param ManualWebhookRequest manual_webhook_request: DTO for webhook request. (required)
        :return: DefaultOfstring
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'manual_webhook_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method trigger_timestamp_webhook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `trigger_timestamp_webhook`")  # noqa: E501
        # verify the required parameter 'manual_webhook_request' is set
        if ('manual_webhook_request' not in params or
                params['manual_webhook_request'] is None):
            raise ValueError("Missing the required parameter `manual_webhook_request` when calling `trigger_timestamp_webhook`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'manual_webhook_request' in params:
            body_params = params['manual_webhook_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API Key Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/v3/webhook/start', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultOfstring',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    OriginStamp API Documentation

    The following documentation describes the API v3 for OriginStamp. OriginStamp is a trusted timestamping service that uses the decentralized blockchain to store anonymous, tamper-proof timestamps for any digital content. OriginStamp allows users to timestamp files, emails, or plain text, and subsequently store the created hashes in the blockchain as well as retrieve and verify timetamps that have been committed to the blockchain.The trusted timestamping service of OriginStamp allows you to generate a hash fingerprint and prove that it was created at a specific point in time. If you are interested in integrating trusted timestamping into your own project, feel free to use our provided API. The following interactive documentation describes the interfaces and supports your integration. With this documentation you are able to try out the different requests and see the responses. For the authorization, add your API key to the Authorization header of your request.<br/><h2>Timestamping Steps</h2><ol><li><strong>Determine Hash: </strong> Calculate the SHA-256 of your record using a cryptographic library.</li><li><strong>Create Timestamp: </strong>Create a timestamp and add meta information to index it, e.g. a comment. You can also request a notification (email or webhook) once the tamper-proof timestamp has been created.</li><li><strong>Archive original file: </strong>Since we have no access to your original data, you should archive it because the timestamp is only valid in combination with the original file.</li><li><strong>Check Timestamp Status: </strong>Since the timestamps are always transmitted to the blockchain network at certain times, i.e. there is a delay, you can check the status of a hash and thus get the timestamp information.</li><li><strong>Get Timestamp Proof: </strong>As soon as the tamper-proof timestamp has been generated, you should archive the proof (Merkle Tree), which we created in our open procedure, together with the original file. With this proof, the existence of the file can be verified independently of OriginStamp. Here you can choose if the raw proof (xml) is sufficient proof or if you want to have a certificate (pdf).</li></ol><br/><h2>Installation Notes</h2><ul><li>Make sure you set the Authorization header correctly using your API key.</li><li>If a Cloudflare error occurs, please set a custom UserAgent header.</li><li>Please have a look at the models below to find out what each field means.</li></ul>  # noqa: E501

    OpenAPI spec version: 3.0
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from originstamp_client.models.currency_model import CurrencyModel
from originstamp_client.models.default_of_download_link_response import DefaultOfDownloadLinkResponse
from originstamp_client.models.default_of_list_of_currency_model import DefaultOfListOfCurrencyModel
from originstamp_client.models.default_of_timestamp_data import DefaultOfTimestampData
from originstamp_client.models.default_of_timestamp_response import DefaultOfTimestampResponse
from originstamp_client.models.default_of_void import DefaultOfVoid
from originstamp_client.models.default_of_webhook_response import DefaultOfWebhookResponse
from originstamp_client.models.default_ofstring import DefaultOfstring
from originstamp_client.models.default_usage_response import DefaultUsageResponse
from originstamp_client.models.download_link_response import DownloadLinkResponse
from originstamp_client.models.manual_webhook_request import ManualWebhookRequest
from originstamp_client.models.notification import Notification
from originstamp_client.models.proof_request import ProofRequest
from originstamp_client.models.timestamp_bulk_request import TimestampBulkRequest
from originstamp_client.models.timestamp_data import TimestampData
from originstamp_client.models.timestamp_request import TimestampRequest
from originstamp_client.models.timestamp_response import TimestampResponse
from originstamp_client.models.usage_response import UsageResponse
from originstamp_client.models.webhook_request import WebhookRequest
from originstamp_client.models.webhook_response import WebhookResponse



# coding: utf-8

# flake8: noqa

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from originstamp_client.api.api_key_api import APIKeyApi
from originstamp_client.api.bulk_api import BulkApi
from originstamp_client.api.proof_api import ProofApi
from originstamp_client.api.scheduler_api import SchedulerApi
from originstamp_client.api.timestamp_api import TimestampApi
from originstamp_client.api.webhook_api import WebhookApi

# import ApiClient
from originstamp_client.api_client import ApiClient
from originstamp_client.configuration import Configuration
# import models into sdk package
from originstamp_client.models.currency_model import CurrencyModel
from originstamp_client.models.default_of_download_link_response import DefaultOfDownloadLinkResponse
from originstamp_client.models.default_of_list_of_currency_model import DefaultOfListOfCurrencyModel
from originstamp_client.models.default_of_timestamp_data import DefaultOfTimestampData
from originstamp_client.models.default_of_timestamp_response import DefaultOfTimestampResponse
from originstamp_client.models.default_of_void import DefaultOfVoid
from originstamp_client.models.default_of_webhook_response import DefaultOfWebhookResponse
from originstamp_client.models.default_ofstring import DefaultOfstring
from originstamp_client.models.default_usage_response import DefaultUsageResponse
from originstamp_client.models.download_link_response import DownloadLinkResponse
from originstamp_client.models.manual_webhook_request import ManualWebhookRequest
from originstamp_client.models.notification import Notification
from originstamp_client.models.proof_request import ProofRequest
from originstamp_client.models.timestamp_bulk_request import TimestampBulkRequest
from originstamp_client.models.timestamp_data import TimestampData
from originstamp_client.models.timestamp_request import TimestampRequest
from originstamp_client.models.timestamp_response import TimestampResponse
from originstamp_client.models.usage_response import UsageResponse
from originstamp_client.models.webhook_request import WebhookRequest
from originstamp_client.models.webhook_response import WebhookResponse



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from originstamp_client.api_client import ApiClient


class TimestampApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_timestamp(self, authorization, timestamp_request, **kwargs):  # noqa: E501
        """Submission  # noqa: E501

        With this interface you can submit your hash. If your API key is valid, your hash is added  seeds and scheduled for timestamping. You are also able to submit additional information, such as a comment or notification target. If the hash already exists, the 'created' field in the response is set to 'false' and any notification(s) for this hash will be ignored. To later query the status of the hash for a certain blockchain you can use the 'seed_id' field of its inner timestamp structure. This field can be used to query the timestamping status of the selected seed. This is recommended if a large number of hashes were transmitted in a certain time frame. Once a hash is successfully created for a certain crypto currency, we can notify your desired target with the timestamp information (via POST Request). A webhook is triggered as soon as the tamper-proof timestamp with the selected crypto currency has been created.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_timestamp(authorization, timestamp_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param TimestampRequest timestamp_request: DTO for the hash submission. Add all relevant information concerning your hash submission. (required)
        :return: DefaultOfTimestampResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_timestamp_with_http_info(authorization, timestamp_request, **kwargs)  # noqa: E501
        else:
            (data) = self.create_timestamp_with_http_info(authorization, timestamp_request, **kwargs)  # noqa: E501
            return data

    def create_timestamp_with_http_info(self, authorization, timestamp_request, **kwargs):  # noqa: E501
        """Submission  # noqa: E501

        With this interface you can submit your hash. If your API key is valid, your hash is added  seeds and scheduled for timestamping. You are also able to submit additional information, such as a comment or notification target. If the hash already exists, the 'created' field in the response is set to 'false' and any notification(s) for this hash will be ignored. To later query the status of the hash for a certain blockchain you can use the 'seed_id' field of its inner timestamp structure. This field can be used to query the timestamping status of the selected seed. This is recommended if a large number of hashes were transmitted in a certain time frame. Once a hash is successfully created for a certain crypto currency, we can notify your desired target with the timestamp information (via POST Request). A webhook is triggered as soon as the tamper-proof timestamp with the selected crypto currency has been created.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_timestamp_with_http_info(authorization, timestamp_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param TimestampRequest timestamp_request: DTO for the hash submission. Add all relevant information concerning your hash submission. (required)
        :return: DefaultOfTimestampResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'timestamp_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_timestamp" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `create_timestamp`")  # noqa: E501
        # verify the required parameter 'timestamp_request' is set
        if ('timestamp_request' not in params or
                params['timestamp_request'] is None):
            raise ValueError("Missing the required parameter `timestamp_request` when calling `create_timestamp`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'timestamp_request' in params:
            body_params = params['timestamp_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API Key Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/v4/timestamp/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultOfTimestampResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_hash_status(self, authorization, hash_string, **kwargs):  # noqa: E501
        """Status  # noqa: E501

        This interface returns information of a certain hash read from the URL path. If the status of several hashes is to be checked, it is preferable to use the seed status interface. This reduces the required requests and can be tailored to a desired blockchain. All 'created' fields are always set to false for a status request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_hash_status(authorization, hash_string, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param str hash_string: The hash in string representation. (required)
        :return: DefaultOfTimestampResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_hash_status_with_http_info(authorization, hash_string, **kwargs)  # noqa: E501
        else:
            (data) = self.get_hash_status_with_http_info(authorization, hash_string, **kwargs)  # noqa: E501
            return data

    def get_hash_status_with_http_info(self, authorization, hash_string, **kwargs):  # noqa: E501
        """Status  # noqa: E501

        This interface returns information of a certain hash read from the URL path. If the status of several hashes is to be checked, it is preferable to use the seed status interface. This reduces the required requests and can be tailored to a desired blockchain. All 'created' fields are always set to false for a status request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_hash_status_with_http_info(authorization, hash_string, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param str hash_string: The hash in string representation. (required)
        :return: DefaultOfTimestampResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'hash_string']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_hash_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_hash_status`")  # noqa: E501
        # verify the required parameter 'hash_string' is set
        if ('hash_string' not in params or
                params['hash_string'] is None):
            raise ValueError("Missing the required parameter `hash_string` when calling `get_hash_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'hash_string' in params:
            path_params['hash_string'] = params['hash_string']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API Key Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/v4/timestamp/{hash_string}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultOfTimestampResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_seed_status(self, authorization, seed_id, **kwargs):  # noqa: E501
        """Seed Status  # noqa: E501

        With this interface you can request the status for a certain seed. This is used when checking the status of previously submitted hashes and avoids sending individual status requests for each hash.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_seed_status(authorization, seed_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param str seed_id: ID of the timestamp seed (required)
        :return: DefaultOfTimestampData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_seed_status_with_http_info(authorization, seed_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_seed_status_with_http_info(authorization, seed_id, **kwargs)  # noqa: E501
            return data

    def get_seed_status_with_http_info(self, authorization, seed_id, **kwargs):  # noqa: E501
        """Seed Status  # noqa: E501

        With this interface you can request the status for a certain seed. This is used when checking the status of previously submitted hashes and avoids sending individual status requests for each hash.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_seed_status_with_http_info(authorization, seed_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param str seed_id: ID of the timestamp seed (required)
        :return: DefaultOfTimestampData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'seed_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_seed_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_seed_status`")  # noqa: E501
        # verify the required parameter 'seed_id' is set
        if ('seed_id' not in params or
                params['seed_id'] is None):
            raise ValueError("Missing the required parameter `seed_id` when calling `get_seed_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'seed_id' in params:
            path_params['seed_id'] = params['seed_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API Key Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/v4/timestamp/status/seed/{seed_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultOfTimestampData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from originstamp_client.api_client import ApiClient


class ProofApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_proof(self, authorization, proof_request_url, **kwargs):  # noqa: E501
        """Proof  # noqa: E501

        Generates the download URL for Proof (Seed / Merkle Tree). This interface must be used to obtain the proof or certificate of your tamper-proof timestamp. The parameters are as follows: Cryptocurrency (e.g., Bitcoin, Ethereum,..), type of evidence (e.g., certificate, merkle tree) and the associated hash. The entries are analyzed, e.g., whether a valid timestamp exists for the hash. Then the URL and the filename are returned, with which your proof can be saved. Please note that the download link is only valid for 5 minutes. When using cURL to fetch the proof with the download link make sure to specify \"application/octet-stream\" in the \"Accept\" header.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_proof(authorization, proof_request_url, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param ProofRequest proof_request_url: Information needed to return the proof. (required)
        :return: DefaultOfDownloadLinkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_proof_with_http_info(authorization, proof_request_url, **kwargs)  # noqa: E501
        else:
            (data) = self.get_proof_with_http_info(authorization, proof_request_url, **kwargs)  # noqa: E501
            return data

    def get_proof_with_http_info(self, authorization, proof_request_url, **kwargs):  # noqa: E501
        """Proof  # noqa: E501

        Generates the download URL for Proof (Seed / Merkle Tree). This interface must be used to obtain the proof or certificate of your tamper-proof timestamp. The parameters are as follows: Cryptocurrency (e.g., Bitcoin, Ethereum,..), type of evidence (e.g., certificate, merkle tree) and the associated hash. The entries are analyzed, e.g., whether a valid timestamp exists for the hash. Then the URL and the filename are returned, with which your proof can be saved. Please note that the download link is only valid for 5 minutes. When using cURL to fetch the proof with the download link make sure to specify \"application/octet-stream\" in the \"Accept\" header.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_proof_with_http_info(authorization, proof_request_url, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param ProofRequest proof_request_url: Information needed to return the proof. (required)
        :return: DefaultOfDownloadLinkResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'proof_request_url']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_proof" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_proof`")  # noqa: E501
        # verify the required parameter 'proof_request_url' is set
        if ('proof_request_url' not in params or
                params['proof_request_url'] is None):
            raise ValueError("Missing the required parameter `proof_request_url` when calling `get_proof`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'proof_request_url' in params:
            body_params = params['proof_request_url']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API Key Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/v3/timestamp/proof/url', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultOfDownloadLinkResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from originstamp_client.api.api_key_api import APIKeyApi
from originstamp_client.api.bulk_api import BulkApi
from originstamp_client.api.proof_api import ProofApi
from originstamp_client.api.scheduler_api import SchedulerApi
from originstamp_client.api.timestamp_api import TimestampApi
from originstamp_client.api.webhook_api import WebhookApi



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ProofRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currency': 'int',
        'hash_string': 'str',
        'proof_type': 'int'
    }

    attribute_map = {
        'currency': 'currency',
        'hash_string': 'hash_string',
        'proof_type': 'proof_type'
    }

    def __init__(self, currency=None, hash_string=None, proof_type=None):  # noqa: E501
        """ProofRequest - a model defined in Swagger"""  # noqa: E501

        self._currency = None
        self._hash_string = None
        self._proof_type = None
        self.discriminator = None

        self.currency = currency
        self.hash_string = hash_string
        self.proof_type = proof_type

    @property
    def currency(self):
        """Gets the currency of this ProofRequest.  # noqa: E501

        0: Bitcoin 1: Ethereum 2: AION 100: Südkurier  # noqa: E501

        :return: The currency of this ProofRequest.  # noqa: E501
        :rtype: int
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this ProofRequest.

        0: Bitcoin 1: Ethereum 2: AION 100: Südkurier  # noqa: E501

        :param currency: The currency of this ProofRequest.  # noqa: E501
        :type: int
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def hash_string(self):
        """Gets the hash_string of this ProofRequest.  # noqa: E501

        Hash in HEX representation for which the proof should be created. We allow the use of SHA-256. Note: We handle the hashes in lower-case.  # noqa: E501

        :return: The hash_string of this ProofRequest.  # noqa: E501
        :rtype: str
        """
        return self._hash_string

    @hash_string.setter
    def hash_string(self, hash_string):
        """Sets the hash_string of this ProofRequest.

        Hash in HEX representation for which the proof should be created. We allow the use of SHA-256. Note: We handle the hashes in lower-case.  # noqa: E501

        :param hash_string: The hash_string of this ProofRequest.  # noqa: E501
        :type: str
        """
        if hash_string is None:
            raise ValueError("Invalid value for `hash_string`, must not be `None`")  # noqa: E501

        self._hash_string = hash_string

    @property
    def proof_type(self):
        """Gets the proof_type of this ProofRequest.  # noqa: E501

        Specifies which type of file should be returned. Possible value(s):  0: proof with a seed file (txt) or proof with a merkle tree (xml) 1: proof with a PDF file   Other formats will follow.  # noqa: E501

        :return: The proof_type of this ProofRequest.  # noqa: E501
        :rtype: int
        """
        return self._proof_type

    @proof_type.setter
    def proof_type(self, proof_type):
        """Sets the proof_type of this ProofRequest.

        Specifies which type of file should be returned. Possible value(s):  0: proof with a seed file (txt) or proof with a merkle tree (xml) 1: proof with a PDF file   Other formats will follow.  # noqa: E501

        :param proof_type: The proof_type of this ProofRequest.  # noqa: E501
        :type: int
        """
        if proof_type is None:
            raise ValueError("Invalid value for `proof_type`, must not be `None`")  # noqa: E501

        self._proof_type = proof_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProofRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProofRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
